#!/bin/sh

# File:
#       tserver.init

# Component Name:
#       Server for GEM

# Description:
#       Performs post install processing for the GEM Server

#############################################################################
## Shell Switches
##
## Shell switches and options are put here. However, 'set -x' should only be
## placed before the block of code you wish to debug and not at the beginning
## of this script.

# If any commands exit with a failed status value, do not automatically exit
set +e
set -x

#############################################################################
## Fix Echo
##
## Not all versions of echo will suppress the newline; /usr/ucb/echo will.
## So put "/usr/ucb/echo" in the variable $ECHO if that binary exists;
## otherwise just put "echo" there. Then, whenever we want to echo a line
## WITHOUT a newline, we will use $ECHO.

if test -s "/usr/ucb/echo" ; then       # Check to see if /usr/ucb/echo exists.
        ECHO="/usr/ucb/echo -n"         # Yes, put that in $ECHO
else
        ECHO="echo"                     # No, put echo in $ECHO
fi

#############################################################################
## Tivoli Environment and Variable Initialization
##
## Initialize all of the variable that Tivoli and its API commands will need
## in order to find all of the Tivoli components.

#$ECHO "Initializing the Tivoli environment..."
#TIVENV=/etc/Tivoli/setup_env.sh                # This is the Tivoli init file
#if test -s $TIVENV ; then              # Is the file there?
#       . $TIVENV                       # Yes, so source it
#else                                   # No, file missing
#       echo "Error: file setup_env.sh does not exist."
#       exit 1                          # Bail with error
#fi

OSERV=`objcall 0.0.0 get_oserv`         # Get Tivoli's oserv object Id
if [ $? -ne 0 ] ; then                  # If the exit was bad...
        echo "Error: could not get Tivoli's oserv object Id."
        exit 1                          # Bail with error
fi
export OSERV                            # Make available to subshells

# Get Tivoli's base install directory (for binaries)
INST_DIR=`objcall $OSERV query install_dir`
if [ $? -ne 0 ] ; then                  # If the exit was bad...
        echo "Error: could not get Tivoli's install directory."
        exit 1                          # Bail with error
fi
export INST_DIR                         # Make available to subshells

INTERP=`objcall $OSERV query interp`
if [ $? -ne 0 ] ; then                  # If the exit was bad...
        echo "Error: could not get Tivoli's interp."
        exit 1                          # Bail with error
fi
export INTERP

FULLDIR=$INST_DIR/$INTERP/TDS/server
export FULLDIR

############################################################################################
##
## Check the location of the datbase directories.
##
## If updating a previous release,rename View Customization files to the
## (GEM) IHS02GEM.* and (HOST) IHS02NET.* format.
############################################################################################
   if [ -d $INST_DIR/$INTERP/TDS/server/db/current/datab  ] ; then
      cd  $INST_DIR/$INTERP/TDS/server/db/current/datab
      if [ $? -ne 0 ] ; then
         exit 2
      fi
   fi

set +f

# if IHS00DBC.DB is found it indicates a GEM 2.1 install.
# Rename view customization files.
#
if [ -f IHS00DBC.DB ] ; then

        for  FILE_NAME in IHS00GEM* ; do
        if [ ! -d $FILE_NAME ] ; then
          NEWNAME=`echo $FILE_NAME | sed -e 's#IHS00GEM'#IHS02GEM#`
          mv $FILE_NAME $NEWNAME
        fi
        done

        for  FILE_NAME in IHS00NET* ; do
        if [ ! -d $FILE_NAME ] ; then
          NEWNAME=`echo $FILE_NAME | sed -e 's#IHS00NET'#IHS02NET#`
          mv $FILE_NAME $NEWNAME
        fi
        done
        
        for  FILE_NAME in IHS00SUB* ; do
        if [ ! -d $FILE_NAME ] ; then
          NEWNAME=`echo $FILE_NAME | sed -e 's#IHS00SUB'#IHS02SUB#`
          mv $FILE_NAME $NEWNAME
        fi
        done

fi

if [ -f IHS01DBC.DB ] ; then

        for  FILE_NAME in IHS01GEM* ; do
        if [ ! -d $FILE_NAME ] ; then
          NEWNAME=`echo $FILE_NAME | sed -e 's#IHS01GEM'#IHS02GEM#`
          mv $FILE_NAME $NEWNAME
        fi
        done

        for  FILE_NAME in IHS01NET* ; do
        if [ ! -d $FILE_NAME ] ; then
          NEWNAME=`echo $FILE_NAME | sed -e 's#IHS01NET'#IHS02NET#`
          mv $FILE_NAME $NEWNAME
        fi
        done
        
        for  FILE_NAME in IHS01SUB* ; do
        if [ ! -d $FILE_NAME ] ; then
          NEWNAME=`echo $FILE_NAME | sed -e 's#IHS01SUB'#IHS02SUB#`
          mv $FILE_NAME $NEWNAME
        fi
        done

fi

if [ $INTERP = "solaris2" ] ; then
  if [ -f $INST_DIR/$INTERP/TDS/server/db/current/datab/IHS01184.DB ] ; then
    if [ ! -f $INST_DIR/$INTERP/TDS/server/db/migratedSun/IHS01184.DB ] ; then
      if [ ! -f $INST_DIR/$INTERP/TDS/server/bin/ihaunpack ] ; then
        if [ -f $INST_DIR/$INTERP/TDS/server/db/current/datab/IHS01TEMP ] ; then
          rm $INST_DIR/$INTERP/TDS/server/db/current/datab/IHS01TEMP
        fi
        $BINDIR/TDS/server/bin/ihszupdt $INST_DIR/$INTERP/TDS/server/db/current/datab/IHS01184.DB $INST_DIR/$INTERP/TDS/server/db/current/datab/IHS01TEMP
        if [ $? = 0 ] ; then
          if [ -f $INST_DIR/$INTERP/TDS/server/db/current/datab/IHS01TEMP ] ; then
            if [ ! -d $INST_DIR/$INTERP/TDS/server/db/migratedSun ] ; then
              mkdir $INST_DIR/$INTERP/TDS/server/db/migratedSun
            fi
            mv $INST_DIR/$INTERP/TDS/server/db/current/datab/IHS01184.DB $INST_DIR/$INTERP/TDS/server/db/migratedSun/IHS01184.DB
            mv $INST_DIR/$INTERP/TDS/server/db/current/datab/IHS01TEMP $INST_DIR/$INTERP/TDS/server/db/current/datab/IHS01184.DB
            chmod 664 $INST_DIR/$INTERP/TDS/server/db/current/datab/IHS01184.DB fi
          fi
        else
          echo "Error.... unable to convert IHS01184.DB"
        fi
      fi
    fi
  fi
fi

set -f


PATH=$FULLDIR:$INST_DIR/$INTERP/TDS/server:/bin:/usr/bin:$BINDIR/AEF:$PATH   # Add to the current PATH

cd $FULLDIR
cd bin

# if [ $INTERP = "aix4-r1" ] || [ $INTERP = "solaris2" ] ; then
  ./unix.setup.sh
# fi

#
# touch all client downloadable files
#
./tserver.touch.sh $INST_DIR/$INTERP

#
#./installTServer.sh
#

echo $DONE
echo " "
