#!/bin/sh

# File:
#       tserver.prep

# Component Name:
#       Server for GEM

# Description:
#       Performs preinstall processing for the GEM Server

#############################################################################
## Shell Switches
##
## Shell switches and options are put here. However, 'set -x' should only be 
## placed before the block of code you wish to debug and not at the beginning 
## of this script.

# If any commands exit with a failed status value, do not automatically exit
set +e
set -x

#############################################################################
## Fix Echo
##
## Not all versions of echo will suppress the newline; /usr/ucb/echo will. 
## So put "/usr/ucb/echo" in the variable $ECHO if that binary exists;
## otherwise just put "echo" there. Then, whenever we want to echo a line
## WITHOUT a newline, we will use $ECHO.

if test -s "/usr/ucb/echo" ; then       # Check to see if /usr/ucb/echo exists.
        ECHO="/usr/ucb/echo -n"         # Yes, put that in $ECHO
else
        ECHO="echo"                     # No, put echo in $ECHO
fi

#############################################################################
## Tivoli Environment and Variable Initialization
##
## Initialize all of the variable that Tivoli and its API commands will need
## in order to find all of the Tivoli components.

#$ECHO "Initializing the Tivoli environment..."
#TIVENV=/etc/Tivoli/setup_env.sh                # This is the Tivoli init file
#if test -s $TIVENV ; then              # Is the file there?
#       . $TIVENV                       # Yes, so source it
#else                                   # No, file missing
#       echo "Error: file setup_env.sh does not exist."
#       exit 1                          # Bail with error
#fi

OSERV=`objcall 0.0.0 get_oserv`         # Get Tivoli's oserv object Id
if [ $? -ne 0 ] ; then                  # If the exit was bad...
        echo "Error: could not get Tivoli's oserv object Id."
        exit 1                          # Bail with error
fi
export OSERV                            # Make available to subshells

# Get Tivoli's base install directory (for binaries)
INST_DIR=`objcall $OSERV query install_dir`
if [ $? -ne 0 ] ; then                  # If the exit was bad...
        echo "Error: could not get Tivoli's install directory."
        exit 1                          # Bail with error
fi
export INST_DIR                         # Make available to subshells

INTERP=`objcall $OSERV query interp`
if [ $? -ne 0 ] ; then                  # If the exit was bad...
        echo "Error: could not get Tivoli's interp."
        exit 1                          # Bail with error
fi
export INTERP

FULLDIR=$INST_DIR/$INTERP/TDS/server
export FULLDIR

############################################################################################
##
## Check the location of the datbase directories.  They may be in the default installation
## directory or a user specified directory indicated by the TSERVER_DB environment variable
##
## If updating to a new release, remove the old files from the default\datab directory
############################################################################################

if [ -n "$TSERVER_DB" ] ; then
   if [ -d $TSERVER_DB/default/datab  ] ; then
      cd $TSERVER_DB/default/datab 
      if [ $? -ne 0 ] ; then    
         exit 2
      fi
   fi
else
   if [ -d $INST_DIR/$INTERP/TDS/server/db/default/datab  ] ; then
      cd  $INST_DIR/$INTERP/TDS/server/db/default/datab 
      if [ $? -ne 0 ] ; then    
         exit 2
      fi
   fi
fi
 

set +f

# If IHS00DBC.DB is found, it indicates it is GEM 2.1.  Delete IHS00*.* files in default\datab 
#


if [ -f IHS00DBC.DB ] ; then

    for FILE_NAME in IHS00* ; do
     if [ ! -d $FILE_NAME ] ; then
       # echo "Removing File."
       rm $FILE_NAME 
     fi
   done

fi

# If IHS01DBC.DB is found, it indicates it is GEM 2.2  Delete IHS01*.*
# files in default\datab
#


if [ -f IHS01DBC.DB ] ; then

    for FILE_NAME in IHS01* ; do
     if [ ! -d $FILE_NAME ] ; then
       # echo "Removing File."
       rm $FILE_NAME 
     fi
   done

fi

      
  
set -f



PATH=$FULLDIR:$INST_DIR/$INTERP/TDS/server:/bin:/usr/bin:$BINDIR/AEF:$PATH   # Add to the current PATH

## cd $FULLDIR
## cd bin 


echo $DONE
echo " "
