#!/bin/sh
#
#***********************************************************************
# Licensed Materials - Property of Tivoli Systems
# 5697-GEM
# (C) COPYRIGHT Tivoli Systems, an IBM Company 1997, 2000
# All rights reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#***********************************************************************
# File:
#       tserver.rc.sh
#
# Component Name:
#       GEM Server
#
# Description:
#       Configures the appropriate remote control interface module
#
# NOTE: rc(5902) indicates that the etc/Tivoli/setup_env.sh file could
#       not be found.  Therefore the Tivoli environment could not be
#       established.
#***********************************************************************
GEM_ROOT="/TDS/server"

usage()
 {
   echo "usage: tserver.rc.sh 36 | 21"
   echo "  36 converts to Remote Control 3.6.x"
   echo "  21 converts to Remote Control 2.1.x"
 }

#
# Setup the Tivoli environment
#
if [ -n "$TSERVER_ETC" ] ; then
  if [ -f $TSERVER_ETC/setup_env.sh ] ; then
    if [ -n "$windir" ] ; then
      if [ -z "$T_SERVT" ] ; then
        source $TSERVER_ETC/setup_env.sh
      fi
      TDS_OS="PC"
    elif [ -n "$OS2_SHELL" ] ; then
      TDS_OS="OS2"
    else
      if [ -z "$T_SERVT" ] ; then
        . $TSERVER_ETC/setup_env.sh
      fi
      TDS_OS="RISC"
    fi
  else
    echo "rc(5902) setup_env.sh not found"
    exit 1
  fi
else
  if [ -n "$windir" ] ; then
    WINOS=`echo $windir | awk /:/'{ print substr($1,4) }'`
    WINDRIVE=`echo $windir | awk /:/'{ print substr($1,1,2) }'`
    if [ -n "$WINOS" ] ; then
      if [ -f $WINDRIVE/$WINOS/system32/drivers/etc/Tivoli/setup_env.sh ] ; then
        if [ -z "$T_SERVT" ] ; then
          source $WINDRIVE/$WINOS/system32/drivers/etc/Tivoli/setup_env.sh
        fi
        TDS_OS="PC"
      else
        echo "rc(5902) setup_env.sh not found"
        exit 1
      fi
    else
      echo "rc(5902) setup_env.sh not found"
      exit 1
    fi
  elif [ -n "$OS2_SHELL" ] ; then
    if [ -n "$BINDIR" ] ; then
      TDS_OS="OS2"
    else
      echo "rc(5902) setup_env.sh not found"
      exit 1
    fi
  elif [ -f /etc/Tivoli/setup_env.sh ] ; then
    if [ -z "$T_SERVT" ] ; then
      . /etc/Tivoli/setup_env.sh
    fi
    TDS_OS="RISC"
  else
    echo "rc(5902) setup_env.sh not found"
    exit 1
  fi
fi
echo 'BINDIR...' $BINDIR


#
# Set LANG
#
if [ -n "$LANG" ] ; then
  if [ ! -d $BINDIR$GEM_ROOT/msg_cat/$LANG ] ; then
    LANG=C
    export LANG
  fi
else
  LANG=C
  export LANG
fi

echo 'LANG.....' $LANG
#
# Set NLSPATH
#
if [ -n $NLSPATH ] ; then
  NLSPATH=$NLSPATH:$BINDIR$GEM_ROOT/msg_cat/%L/%N:$BINDIR$GEM_ROOT/msg_cat/%L/%N.cat
else
  NLSPATH=$BINDIR$GEM_ROOT/msg_cat/%L/%N:$BINDIR$GEM_ROOT/msg_cat/%L/%N.cat
fi
export NLSPATH

#
# Set PATH
#
if [ "`uname`" = "SunOS" ] ; then
  PATH=/bin:/usr/bin:/sbin:/usr/sbin:/usr/ucb:/usr/dt/bin:$PATH
  LD_LIBRARY_PATH=$LD_LIBRARY_PATH:/usr/dt/lib:$BINDIR$GEM_ROOT/lib
  export LD_LIBRARY_PATH
fi

if [ -z "$T_SERVP" ] ; then
  PATH=$PATH:$BINDIR$GEM_ROOT/bin:$BINDIR$GEM_ROOT/msg_cat/$LANG
fi
export PATH

#
# Set beginlibpath for os/2
#
if [ $TDS_OS = "OS2" ] ; then
  BEGINLIBPATH=$BINDIR$GEM_ROOT/bin\;$BINDIR$GEM_ROOT/msg_cat/$LANG
  export BEGINLIBPATH
fi

#
# Ensure that /usr/lib is not in LIBPATH
#
if [ $TDS_OS = "RISC" ] ; then
  if [ -n "$LIBPATH" ] ; then
    tmpLibPath=`echo $LIBPATH | sed -e 's#/usr/lib:'##g`
    tmpLibPath=`echo $tmpLibPath | sed -e 's#:/usr/lib$'##`
    if [ -z "$tmpLibPath" ] ; then
      unset LIBPATH
    elif [ "$tmpLibPath" = "/usr/lib" ] ; then
      unset LIBPATH
    else
      LIBPATH=$tmpLibPath
      export LIBPATH
    fi
  fi

#
# Ensure that /usr/lpp/X11/lib/R5 is not in LIBPATH
#
  if [ -n "$LIBPATH" ] ; then
    tmpLibPath=`echo $LIBPATH | sed -e 's#/usr/lpp/X11/lib/R5:'##g`
    tmpLibPath=`echo $tmpLibPath | sed -e 's#:/usr/lpp/X11/lib/R5$'##`
    if [ -z "$tmpLibPath" ] ; then
      unset LIBPATH
    elif [ "$tmpLibPath" = "/usr/lpp/X11/lib/R5" ] ; then
      unset LIBPATH
    else
      LIBPATH=$tmpLibPath
      export LIBPATH
    fi
  fi
fi

#
# You must be root
#
if [ $TDS_OS = "RISC" ] ; then
  if [ "`whoami`" != "root" ]
   then
    command $BINDIR$GEM_ROOT/bin/ihszmsgp 2 5901
    exit 1
   fi
fi

#
# Switch the remote control interface modules
#
if [ "$1" = "" ] ; then
  usage
  exit 1
elif [ "$1" = "36" ] ; then
  if [ -f $BINDIR$GEM_ROOT/db/current/bin/ihsmrc36.exe ] ; then
    if [ -f $BINDIR$GEM_ROOT/db/current/bin/ihsmrmcl.exe ] ; then
      rm $BINDIR$GEM_ROOT/db/current/bin/ihsmrmcl.exe
    fi

    cp $BINDIR$GEM_ROOT/db/current/bin/ihsmrc36.exe $BINDIR$GEM_ROOT/db/current/bin/ihsmrmcl.exe

    touch $BINDIR$GEM_ROOT/db/current/bin/ihsmrmcl.exe

    echo "Support for Remote Control 3.6.x has been configured."
    echo "This support will be downloaded to each console the"
    echo "next time they signon to the server."

    if [ ! -f $BINDIR$GEM_ROOT/db/current/bin/wrc.exe ] ; then
      echo "Note:"
      echo "  File $BINDIR$GEM_ROOT/db/current/bin/wrc.exe is missing."
      echo "  This file must be copied from the Remote Control server to"
      echo "  the $BINDIR$GEM_ROOT/db/current/bin directory on `hostname`."
    fi
  else
    echo "Unable to find $BINDIR$GEM_ROOT/db/current/bin/ihsmrc36.exe"
    echo "Remote Control interface modules has not been changed to 3.6.x"
  fi
elif [ "$1" = "21" ] ; then
  if [ -f $BINDIR$GEM_ROOT/db/current/bin/ihsmrc21.exe ] ; then
    if [ -f $BINDIR$GEM_ROOT/db/current/bin/ihsmrmcl.exe ] ; then
      rm $BINDIR$GEM_ROOT/db/current/bin/ihsmrmcl.exe
    fi

    cp $BINDIR$GEM_ROOT/db/current/bin/ihsmrc21.exe $BINDIR$GEM_ROOT/db/current/bin/ihsmrmcl.exe

    touch $BINDIR$GEM_ROOT/db/current/bin/ihsmrmcl.exe

    echo "Support for Remote Control 2.1.x has been configured."
    echo "This support will be downloaded to each console the"
    echo "next time they signon to the server."
  else
    echo "Unable to find $BINDIR$GEM_ROOT/db/current/bin/ihsmrc21.exe"
    echo "Remote Control interface modules has not been changed to 2.1.x"
  fi
else
   usage
   exit 1
fi

exit 0
