/*
********************************************************************************
*
* Licensed Materials - Property of IBM
*
* This product contains "Restricted Materials of IBM"
*
* 5697-B82 (C) Copyright IBM Corp. 1997, 2001
* All Rights Reserved.
*
********************************************************************************
*
* PRODUCT          (NMC)
* COMPONENT        (IHSI)
*
* MODULE_NAME      (ihsiexit.h)
* DESCRIPTIVE_NAME (IHS command exit interface header file)
*
********************************************************************************
*
* Function:
*   Provide C definitions for IHS command exit constants, structures, and
*   function prototypes.
*
*******************************************************************************/

/******************************************************************************/
/* Have we been included already?                                             */
/******************************************************************************/
#ifndef IHSIEXIT_H

#define IHSIEXIT_H

#ifndef     IHSPXAPI_H
  #include "ihspxapi.h"                     /* eXternal API definitions       */
#endif

/******************************************************************************/
/* Ensure proper structure packing                                            */
/******************************************************************************/
#ifndef _AIX
  #pragma pack(1)
#else
  #pragma options align=packed
#endif

#ifndef _GNU_PACKED
  #ifdef SOLARIS
    #define _GNU_PACKED __attribute__ ((packed))
  #else
    #define _GNU_PACKED
  #endif
#endif

/******************************************************************************/
/* Command Exit Termination Semaphore Name                                    */
/******************************************************************************/
#ifdef __OS2__
  #define EGVE_TERMINATE_SEM         "\\SEM32\\IHSIEXIT"
#endif

#ifdef __WINDOWS__
  #define EGVE_TERMINATE_SEM         "SEM32.INTERAPP.IHSIEXIT"
#endif

#ifdef __UNIX__
  #define EGVE_TERMINATE_SEM         "SEM/INTERAPP.IHSIEXIT.SEM"
#endif

/******************************************************************************/
/* Length constants                                                           */
/******************************************************************************/
#define L_OP_ID                      8
#define L_OP_PW                      8
#define L_IP_ADDR                    8
#define L_EXIT_NAME                  8
#define L_RODM_ID                    8
#define L_NV_DOMAIN_ID               5
#define L_RESERVED1                  26
#define L_RESERVED2                  64
#define L_MAX_COMMAND_BUFFER         32 * 1024

#define EGVE_MAX_HOST_CMD_LEN        255

/******************************************************************************/
/* Exit procedure return codes                                                */
/******************************************************************************/
#define EGVE_EXIT_OK                           0x0000

#define EGVE_EXIT_NOT_LOADED                   0x8001
#define EGVE_EXIT_FAIL                         0x8002
#define EGVE_EXIT_NO_OPER                      0x8004
#define EGVE_EXIT_INVALID_CMD                  0x8005
#define EGVE_EXIT_HOST_DOWN                    0x8006
#define EGVE_EXIT_NO_DOMAINS                   0x8007
#define EGVE_EXIT_OUT_OF_MEMORY                0x8009
#define EGVE_EXIT_OUT_OF_RESOURCES             0x800A
#define EGVE_EXIT_INVALID_DEFINITION           0x800B

#define EGVE_EXIT_TME_TASK_NOT_FOUND           0x800C
#define EGVE_EXIT_TME_CATCH_IN_MAIN            0x800D
#define EGVE_EXIT_TME_INVALID_MANAGEDNODE_NAME 0x800E
#define EGVE_EXIT_TME_INVALID_COMMAND_STRING   0x800F
#define EGVE_EXIT_TME_ERR_GET_ALL_RESOURCES    0x8010
#define EGVE_EXIT_TME_BAD_RETURN_FROM_TAS      0x8011
#define EGVE_EXIT_TME_ERROR_DURING_TASK_EXEC   0x8012
#define EGVE_EXIT_TME_NOT_INITIALIZED          0x8013
#define EGVE_EXIT_TME_CATCH_COMM_FAILURE       0X8014
#define EGVE_EXIT_TME_CATCH_OBJ_APT_FAILURE    0X8015
#define EGVE_EXIT_TME_CATCH_NO_MEMORY          0X8016
#define EGVE_EXIT_TME_CATCH_ALL                0X8017
#define EGVE_EXIT_TME_CATCH_IN_RESPONSE        0X8018

#define EGVE_EXIT_OPER_NOT_AUTH                0x8019
#define EGVE_EXIT_INVALID_NV_DOMAIN            0x801A

#define EGVE_EXIT_TME_BUILDING_LIB_NAME        0X8020
#define EGVE_EXIT_TME_BAD_SEND                 0X8021
#define EGVE_EXIT_TME_INV_OBJ                  0X8022

#define EGVE_EXIT_USER                         0x9000
#define EGVE_EXIT_USER_MAX                     0x9FFF

/******************************************************************************/
/* Exit interface return codes                                                */
/******************************************************************************/
#define EGVE_OK                      0x0000
#define EGVE_ALREADY_STARTED         0x0001
#define EGVE_PARAMETER_CHECK         0x0002
#define EGVE_OUT_OF_MEMORY           0x0003
#define EGVE_NOT_STARTED             0x0004
#define EGVE_HANDLER_NOT_STARTED     0x0005
#define EGVE_DATA_OVERFLOW           0x0006
#define EGVE_INTERNAL_FAILURE        0x0007
#define EGVE_SEM_TIMEOUT             0x0008
#define EGVE_SEM_TERMINATE           0x0009

/******************************************************************************/
/* Parameter for IhsiInit.  Indicates that the registetered exit desires      */
/* multi-threading or single-treading capability.  With single-threading      */
/* desired, each invocation of the exit will be serialized, using the same    */
/* thread.                                                                    */
/******************************************************************************/
#define EGVE_SINGLE_THREADING        0
#define EGVE_MULTI_THREADING         1

/******************************************************************************/
/* Ensure that we get C linkage, even when compiled in C++                    */
/******************************************************************************/
#ifdef __cplusplus
  extern "C" {
#endif

/******************************************************************************/
/* Structure for the correlation id.  Customers should not change the values  */
/* within this structure.  For Intel machines, storage is mapped as           */
/*    3I 12 AB CD      I: invoker_id                                          */
/*                   123: depth                                               */
/*                  ABCD: numb                                                */
/******************************************************************************/
struct _EGVE_CORR_ID
{
  unsigned int invoker_id  : 4 _GNU_PACKED; /* Invoker identifier             */
  unsigned int depth       :12 _GNU_PACKED; /* Calling IhsiSend depth         */
  unsigned int numb        :16 _GNU_PACKED; /* Unique number                  */
};

typedef struct _EGVE_CORR_ID   EGVE_CORR_ID,
                              *EGVE_CORR_ID_PTR;

/******************************************************************************/
/* Structure for time stamps.                                                 */
/******************************************************************************/
struct _EGVE_TIMESTAMP
{
  unsigned short year      _GNU_PACKED;     /* Year    (0 - 65535)            */
  unsigned char  month     _GNU_PACKED,     /* Month   (1 - 12)               */
                 day       _GNU_PACKED,     /* Day     (1 - 31)               */
                 hour      _GNU_PACKED,     /* Hour    (0 - 23)               */
                 min       _GNU_PACKED,     /* Minutes (0 - 59)               */
                 sec       _GNU_PACKED,     /* Seconds (0 - 59)               */
                 tenths    _GNU_PACKED;     /* Tenths  (0 - 9)                */
};

typedef struct _EGVE_TIMESTAMP   EGVE_TIMESTAMP,
                                *EGVE_TIMESTAMP_PTR;

/******************************************************************************/
/* Command Exit Parameter block                                               */
/*                                                                            */
/* When the following fields are send to the console, they are a member of    */
/* the following Console objects:                                             */
/*     RI:  IhsResInfo                                                        */
/*     CI:  IhsCmdInfo                                                        */
/*                                                                            */
/******************************************************************************/
struct _EGVE_PARAMETERS32
{
  /********************************************************************************************/
  /* The following are resource independent fields.                                           */
  /********************************************************************************************/
  char *           command_name          _GNU_PACKED;      /* Menu text, if from CPE        CI*/
  char *           command_string        _GNU_PACKED;      /* Command string             RI/CI*/
  char             exit_name           [ L_EXIT_NAME + 1 ] /* Exit name                  RI/CI*/
                                         _GNU_PACKED;
  char             exit_executable_name[ L_EXIT_NAME + 1 ] /* The name of the executable RI/CI*/
                                         _GNU_PACKED;      /* for the invoked exit.  This is      */
                                                           /* optional and is used only when  */
                                                           /* the name of the exit as         */
                                                           /* specified in exit_name is not   */
                                                           /* the name of the executable to be*/
                                                           /* run.  Nulls or blanks indicates */
                                                           /* that it is not specified.       */
  long             exit_timeout          _GNU_PACKED;      /* Used by some exits to timeout CI*/
                                                           /* extended operations.  Also used */
                                                           /* when a server-based command exit*/
                                                           /* is invoked from the console.    */
                                                           /* This is the number of seconds.  */
                                                           /* 0 means that a timeout hasn't   */
                                                           /* been specified.  -1 means to    */
                                                           /* wait indefinitely. -2 means do  */
                                                           /* not wait, and ignore command    */
                                                           /* responses.                      */
  short            wait_for_cmd_response _GNU_PACKED;      /* Wait, in minutes, for the     CI*/
                                                           /* responses to commands (used by  */
                                                           /* IHSXTHCE only)                  */
  unsigned short   want_corr_of_cmd_rsps _GNU_PACKED;      /* Non zero means that server will */
                                                           /* send command string to console  */
                                                           /* and your command exit will send */
                                                           /* command responses to console via*/
                                                           /* IHSXTJCR (use same              */
                                                           /* correlation_id!)                */
  EGVE_CORR_ID     correlation_id        _GNU_PACKED;      /* Correlation id                CI*/
  unsigned long    client_handle         _GNU_PACKED;      /* IBM internal console id         */
  char             client_ip_addr   [ L_IP_ADDR     + 1 ]  /* IBM internal version of the   CI*/
                                         _GNU_PACKED;      /* socket file descriptor          */
                                                           /* associated with the server's IP */
                                                           /* connection with the console     */
  char             server_ip_addr   [ L_IP_ADDR     + 1 ]  /* Server IP address             CI*/
                                         _GNU_PACKED;
  char *           signon_username       _GNU_PACKED;      /* Console signon username       CI*/
  char             op_id            [ L_OP_ID       + 1 ]  /* NetView390 Operator id, if    CI*/
                                         _GNU_PACKED;      /* available                       */
  unsigned char *  user_data             _GNU_PACKED;      /* User data                     CI*/
  unsigned short   user_data_length      _GNU_PACKED;
  unsigned char *  user_ctrl_data        _GNU_PACKED;      /* User control data             CI*/
  unsigned short   user_ctrl_data_length _GNU_PACKED;
  unsigned long    IBM_menu_id           _GNU_PACKED;      /* IBM internal CPE menu id      CI*/
  int              extended_reason_code  _GNU_PACKED;      /* Set by IhsiSend():              */
                                                           /* Value is dependent on the rc    */
                                                           /* EGVE_DATA_OVERFLOW --           */
                                                           /*    size of buffer send failed on*/
  char *           nv390_hostname        _GNU_PACKED;      /* TCP/IP hostname of NetView390 CI*/
                                                           /* if available                    */
  char *           nv390_ip_addr         _GNU_PACKED;      /* TCP/IP dotted decimal address CI*/
                                                           /* of NetView390 if available      */
  char             nv390_domain     [ L_NV_DOMAIN_ID + 1 ] /* NetView390 Domain id          CI*/
                                         _GNU_PACKED;
  char *           client_hostname       _GNU_PACKED;      /* TCP/IP hostname of console    CI*/
  char *           client_ip_addr_dd     _GNU_PACKED;      /* Dotted decimal IP address of  CI*/
                                                           /* the console                     */
  char             reserved1        [ L_RESERVED1 ]        /* Reserved for future growth      */
                                         _GNU_PACKED;

  /********************************************************************************************/
  /* The following are resource specific fields.                                              */
  /********************************************************************************************/
  char *           display_name          _GNU_PACKED;      /* Resource name (label)         RI*/
  char *           display_resource_type _GNU_PACKED;      /* Display resource type         RI*/
  unsigned long    resource_type         _GNU_PACKED;      /* Hex resource type             RI*/
  unsigned char    resource_status       _GNU_PACKED;      /* Resource status               RI*/
  EGVE_TIMESTAMP   resource_status_ts    _GNU_PACKED;      /* Resource status timestamp     RI*/
  unsigned long    resource_flags        _GNU_PACKED;      /* Resource flags                RI*/
  char *           data1                 _GNU_PACKED;      /* Resource specific data1       RI*/
  char *           data2                 _GNU_PACKED;      /* Resource specific data2       RI*/
  char *           data3                 _GNU_PACKED;      /* Resource specific data3       RI*/
  char *           data4                 _GNU_PACKED;      /* Resource specific data4       RI*/
  unsigned short   data_source           _GNU_PACKED;      /* Data source                   RI*/
  unsigned short   command_indicator     _GNU_PACKED;      /* Command indicator             RI*/
  char             resource_RODM_id [ L_RODM_ID ]          /* NetView390 RODM object id     RI*/
                                         _GNU_PACKED;
  unsigned char *  user_res_data         _GNU_PACKED;      /* User resource data            RI*/
  unsigned short   user_res_data_length  _GNU_PACKED;
  unsigned long    res_IBM_id            _GNU_PACKED;      /* IBM internal resource id      RI*/

  /* The following fields (prefixed with hb_) originate in the TEC Event                      */
  /* Heartbeat.  See the definition of the TEC Event Heartbeat for the                        */
  /* precise definititon.  Also, for TEC Event Heartbeats, the hb_data1, hb_data2, hb_data3   */
  /* and hb_data4 fields are filled into the above data1, data2, data3, and data4 fields.     */
  char *           hb_source             _GNU_PACKED;      /* Resource application name:    RI*/
                                                           /* "Manufacturer;Product;Version"  */
                                                           /* from the ComponentID group.     */
  char *           hb_sub_source         _GNU_PACKED;      /* Resource "Manufacturer;       RI*/
                                                           /* ComponentID;Version" from CDF   */
  char *           hb_origin             _GNU_PACKED;      /* Identifies the system on      RI*/
                                                           /* which the component resides     */
                                                           /* (enum-value pair list)          */
  char *           hb_sub_origin         _GNU_PACKED;      /* Resource instance identifier, RI*/
                                                           /* differentiates between          */
                                                           /* components on same system       */
                                                           /* (enum-value pair list)          */
  char *           hb_hostname           _GNU_PACKED;      /* Distributed resource:  TCPIP  RI*/
                                                           /* hostname of the system.         */
                                                           /* Host resource:  NetView domain  */
                                                           /* name.                           */
  char *           hb_es_managed_node    _GNU_PACKED;      /* Managed node of the local     RI*/
                                                           /* TEC, where more information     */
                                                           /* on the resource can be gathered */
  char *           business_sys_name     _GNU_PACKED;      /* Resource business system name RI*/
                                                           /* (in context of a view), if      */
                                                           /* available                       */
  unsigned char *  IBM_data              _GNU_PACKED;      /* IBM internal use only data      */
  unsigned short   IBM_data_length       _GNU_PACKED;

  char *           resource_TME_oid      _GNU_PACKED;      /* TME object id                 RI*/

  char             reserved2        [ L_RESERVED2 ]        /* Reserved for future growth      */
                                         _GNU_PACKED;
};

typedef struct _EGVE_PARAMETERS32   EGVE_PARAMETERS32;
typedef struct _EGVE_PARAMETERS32 * EGVE_PARAMETERS32_PTR;

/******************************************************************************/
/* Structures passed to IHSXTJCR exit.  This exit is used to pass commands or */
/* command responses, to the console, to be displayed on the console's log.   */
/*                                                                            */
/* In the user_data field, the actual strings (commands and/or command        */
/* responses) are to be sent to the IHSXTJCR exit.  user_data is a pointer to */
/* a linear series of struct EGVE_CMD_RSP.                                    */
/******************************************************************************/
struct _EGVE_CMD_RSP_CTRL                   /* user_ctrl_data field           */
{
  unsigned long   isComplete   _GNU_PACKED; /* Is this series of strings the  */
                                            /* end of the strings for this    */
                                            /* command (ie, for this          */
                                            /* correlation_id)?  0 = More to  */
                                            /* come.  Any other value means   */
                                            /* complete.                      */
};

typedef struct _EGVE_CMD_RSP_CTRL     EGVE_CMD_RSP_CTRL,
                                     *EGVE_CMD_RSP_CTRL_PTR;

struct _EGVE_CMD_RSP                        /* user_data field                */
{
  unsigned short  cmdRspLen    _GNU_PACKED; /* Length of the string (does not */
                                            /* include length field, only the */
                                            /* string)                        */
  unsigned short  cmdRspType   _GNU_PACKED; /* Type of string.  The string can*/
                                            /* be either a command or a       */
                                            /* command response.              */
  unsigned char   cmdRspStr[1] _GNU_PACKED; /* Command or command response    */
                                            /* string.  Does not have to be   */
                                            /* null terminated.               */
};

typedef struct _EGVE_CMD_RSP          EGVE_CMD_RSP,
                                     *EGVE_CMD_RSP_PTR;

#define EGVE_CMD_RSP_TYPE_CMD        0
#define EGVE_CMD_RSP_TYPE_RSP        1
#define EGVE_CMD_RSP_STR_OFFSET   ((int)&(((EGVE_CMD_RSP_PTR)0)->cmdRspStr[0]))

/******************************************************************************/
/* Definition for pointer to exit procedure                                   */
/******************************************************************************/
typedef unsigned int (PXAPI EGVE_EXIT_PROC_ADDR32)( EGVE_PARAMETERS32_PTR );

/******************************************************************************/
/* Exit interface function prototypes.                                        */
/******************************************************************************/
XAPI_C unsigned int XAPI
IhsiInitialize ( const char *          exit_name
               , EGVE_EXIT_PROC_ADDR32 exit_procedure_addr );

XAPI_C unsigned int XAPI
IhsiInit( const char *           exit_name
        , EGVE_EXIT_PROC_ADDR32  exit_procedure_addr
        , unsigned long          thread_type );

XAPI_C unsigned int XAPI
IhsiTerminate ( const char * exit_name );


XAPI_C unsigned int XAPI
IhsiSend ( const char *          source_exit_name
         , const char *          dest_exit_name
         , const char *          dest_ip_addr
         , EGVE_PARAMETERS32_PTR parms_ptr );

XAPI_C unsigned int XAPI
IhsiWait ( char * exit_name
         , int    seconds );

#ifndef _AIX
  #pragma pack()
#else
  #pragma options align=reset
#endif


#ifdef __cplusplus
  };
#endif

#endif
