/*                                       TEMPLATE LEVEL = 05/01/90
********************************************************************************
*
* Licensed Materials - Property of IBM
*
* This product contains "Restricted Materials of IBM"
*
* 5655-007 (C) Copyright IBM Corp. 1997, 1997
* All Rights Reserved.
*
********************************************************************************
*
* PRODUCT          (TME 10 GEM APM)
* COMPONENT        (IHSP)
* FIRST_RELEASE    (V1R1)
* LAST_CHANGE      (V1R1)
*
* MODULE_NAME      (ihspxapi.h)
* DESCRIPTIVE_NAME (Cross-platform definitions for external C function APIs) 
*
********************************************************************************
*
*                       Module Level Design
*
********************************************************************************
*
* Function:
*   Provide cross-platform definitions for external C function APIs
*
*   The compiler option required for externalized C functions varies by:
*
*   1) compiler/target platform....OS/2, Windows NT, AIX, etc
*   2) compiler "mode".............C vs. C++
*   3) number of API arguments.....fixed, variable
*
*
* Notes:
*
*   - the following macros are defined according to the above criteria:
*
*     linkage conventions for externalized C functions
*     ====================================================
*       XAPI            =            32 bit C function
*      PXAPI            = pointer to 32 bit C function
*       XAPI_VA         =            32 bit C function with variable arguments
*
*     C++ compile of externalized C functions
*     ====================================================
*       XAPI_C        = single         C API definition
*       XAPI_C_BEGIN  = begin block of C API definitions
*       XAPI_C_END    = end   block of C API definitions
*
********************************************************************************
*
* CHANGE ACTIVITY:
* ------------------------------------------------------------------------------
*   - V1R1....added in V1R1 Base Release
*
*******************************************************************************/

/******************************************************************************
* Already included?
******************************************************************************/
#ifndef   IHSPXAPI_H

#  define IHSPXAPI_H

/******************************************************************************
* AIX specific definitions
******************************************************************************/
#  ifdef __UNIX__

#    define  XAPI
#    define PXAPI    * XAPI

#    define  XAPI_VA

#  endif

/******************************************************************************
* OS/2 specific definitions
******************************************************************************/
#  ifdef __OS2__

#    define  XAPI    __stdcall
#    define PXAPI    * XAPI

#    define  XAPI_VA _Optlink

#  endif

/******************************************************************************
* Windows NT specific definitions
******************************************************************************/
#  ifdef __WINDOWS__

#    define  XAPI    __stdcall
#    define PXAPI    * XAPI

#    define  XAPI_VA _Optlink

#  endif


/******************************************************************************
* C++ specific definitions
*
* Note: this prevents the C++ compiler from "name mangling" external C
*       API function names
******************************************************************************/
#  ifdef __cplusplus

#    define XAPI_C          extern "C"       /* for single   C API function  */

#    define XAPI_C_BEGIN    XAPI_C {         /* for block of C API functions */
#    define XAPI_C_END             }

#  else

#    define XAPI_C

#    define XAPI_C_BEGIN
#    define XAPI_C_END

#  endif

#endif
