/*******************************************************************************
*
* Licensed Materials - Property of Tivoli Systems
* 5697-GEM
* (C) Copyright IBM Corp. 1999, 1999.  All rights reserved.
*
* US Government Users Restricted Rights - Use, duplication or
* disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
*
* SAMPLE PROGRAM - NO WARRANTY EXPRESSED OR IMPLIED
*
* You are hereby licensed to use, reproduce, and distribute these sample
* programs as your needs require.  IBM does not warrant the suitability or
* integrity of these sample programs and accepts no responsibility for their
* use for your applications.  If you choose to copy and redistribute
* significant portions of these sample programs, you should preface such
* copies with this copyright notice.
*
********************************************************************************
*
* PRODUCT          (Tivoli GEM/NMC)
* COMPONENT        (IHSS)
* FIRST_RELEASE    (V2R3/V1R3)
* LAST_CHANGE      (V2R3/V1R3)
*
* MODULE_NAME      (IHSSAMCE.C)
* DESCRIPTIVE_NAME (Sample command exit that is launched from a console context menu)
*
********************************************************************************
*
*                       Module Level Design
*
********************************************************************************
*
* WARNING:
*
*   When calling IhsiSend, do NOT pass in the EGVE_PARAMETERS32 structure
*   with any fields pointing to static data.  Upon return from the
*   IhsiSend, the EGVE_PARAMETERS32 structure is refreshed; the fields
*   pointing to static data will cause a trap, because they cannot
*   be written into.
*
* Function:
*
*   This sample command exit shows how to registers this command exit
*   with the command exit facility, and then shows three ways to handle
*   command responses:
*
*     1) Invoking IHSXTHCE to execute a NetView390 command, and getting
*        back the command responses.  Nothing will be displayed in the
*        console's log window.
*     2) Building command responses inside this command exit, and sending
*        them to the console's log window.
*     3) Invoking IHSXTHCE to execute a NetView390 command, and letting the
*        server send the command and command responses to the console's
*        log window.
*
*   An example of how to add this command exit to the console's context menu:
*
*     %BINDIR%\TDS\server\bin\cpebatch ..\sample\ihssamce.en_US.rsp -i -g
*
*
* Compile & link instructions:
*
*   For WindowsNT, an example command to compile and link using VisualAge for C++ for NT:
*
*     set include=%include%;%BINDIR%\TDS\server\sample
*     set lib=%lib%;%BINDIR%\TDS\server\lib;
*     icc /Gm+ /Ti+ ihssamce.c ihsiexit.lib wsock32.lib
*
*   For OS/2, an example command to compile and link using VisualAge for C++ for OS/2:
*
*     set include=%include%;%BINDIR%\TDS\server\sample;D:\IBMCPP30\INCLUDE\sys;d:\tcpip30\include
*     set lib=%lib%;%BINDIR%\TDS\server\lib;d:\tcpip30\lib
*     icc /Gm+ /Ti+ ihssamce.c ihsiexit.lib so32dll.lib tcp32dll.lib
*
*   For AIX, an example command to compile and link using VisualAge for C++ for AIX:
*
*     cc_r7 -g -D__UNIX__ -D_AIX -I$BINDIR/TDS/server/sample -qcpluscmt -c ihssamce.c
*     xlC_r7 -o ihssamce -L$BINDIR/TDS/server/lib -lihsiexit -legvz -lexqu -legvc -los2 -lcxxbase -lfmgda -lfmgdb ihssamce.o
*
*
*******************************************************************************/

#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include <malloc.h>
#include <time.h>
#include <stdlib.h>

#ifndef __UNIX__
  #include <conio.h>
  #include <process.h>
  #define F_BINARY "b"
#endif

#ifdef __UNIX__
  #include <sys/types.h>
  #include <netdb.h>
  #include <sys/socket.h>
  #include <netinet/in.h>
  #include <arpa/inet.h>
  #include <errno.h>
  #include <locale.h>
  #define F_BINARY ""
  #include <netdb.h>
  #include <sys/utsname.h>
  /* fudge Wintel-isms */
  typedef ushort BOOL;
  typedef ushort HMODULE;
  typedef char* PSZ;
  #define strnicmp strncasecmp
  #define strcmpi  strcasecmp
#endif

#ifdef __WINDOWS__
  #include <windows.h>
  #include "ihsnont.h"
  #include <winsock.h>
#endif

#ifdef __OS2__
  #include <os2.h>
  #include <types.h>
  #include <netdb.h>
  #include <sys/socket.h>
  #include <sys/un.h>
  #include <sys/ioctl.h>
  #include <netinet/in.h>
#endif

#include "ihsiexit.h"


/******************************************************************************/
/* This is the name of this command exit.  It must be 8 characters or less and*/
/* must be a unique command exit name.                                        */
/******************************************************************************/
#define EXIT_NAME "IHSSAMCE"


/******************************************************************************/
/*                                                                            */
/* Print the Command Response strings in the communcation server's command    */
/* prompt window.                                                             */
/*                                                                            */
/******************************************************************************/
void IhsSamCE_Cmd_Rsp( EGVE_PARAMETERS32_PTR parms )
{
  EGVE_CMD_RSP_PTR  pCmdRsp;
  unsigned short    lenCtr;
  unsigned short    prevLen;
  void             *pTmpStr;

  /****************************************************************************/
  /* Peel out the Command Response strings from user_data.  Only do this if   */
  /* the size and pointer is ok.                                              */
  /****************************************************************************/
  if ( parms->user_data_length > 0
    && NULL != parms->user_data )
  {
    /**************************************************************************/
    /* Set up ptr to point to first set of len-str pairs.                     */
    /**************************************************************************/
    pCmdRsp = (EGVE_CMD_RSP_PTR)parms->user_data;
    lenCtr  = pCmdRsp->cmdRspLen + EGVE_CMD_RSP_STR_OFFSET;

    /**************************************************************************/
    /* While the length so far is less than or equal to total length.  This   */
    /* length includes the length of the current string to be processed.      */
    /**************************************************************************/
    while (lenCtr <= parms->user_data_length)
    {
      /************************************************************************/
      /* Create a temporary string of this particular command response string.*/
      /************************************************************************/
      pTmpStr = calloc(pCmdRsp->cmdRspLen + 1, 1);

      memcpy( (unsigned char *)pTmpStr
            , pCmdRsp->cmdRspStr
            , pCmdRsp->cmdRspLen );

      /************************************************************************/
      /* Print this single command response string to stdout.                 */
      /************************************************************************/
      printf("%s \n",(unsigned char *)pTmpStr);

      free(pTmpStr);

      /************************************************************************/
      /* If we are processing the very last command response string           */
      /************************************************************************/
      if (lenCtr == parms->user_data_length)
      {
        lenCtr++;                           /* Bump ptr to get out of loop    */
      }
      /************************************************************************/
      /* Else we have more command response strings to process                */
      /************************************************************************/
      else
      {
        /**********************************************************************/
        /* Reset the pointer to the next command response string, and add the */
        /* length of the next string.                                         */
        /**********************************************************************/
        prevLen = pCmdRsp->cmdRspLen;       /* Save current cmd rsp str len   */

        pCmdRsp = (EGVE_CMD_RSP_PTR)
                  (  (unsigned char *)pCmdRsp
                    + EGVE_CMD_RSP_STR_OFFSET
                    + prevLen);

        lenCtr += pCmdRsp->cmdRspLen + EGVE_CMD_RSP_STR_OFFSET;
      }
    }                                       /* End while                      */
  }
}


/******************************************************************************/
/*                                                                            */
/* Copy the fields that are in the EGVE_PARMARTERS32 structure sent to this   */
/* command exit, to a new copy of the EGVE_PARAMATERS32 structure, that are   */
/* required for the IHSXTHCE command exit, when this command exit is invoked  */
/* in context of a selected resource.                                         */
/*                                                                            */
/******************************************************************************/
void IhsSamCE_CopyFieldsForIhsxthce( EGVE_PARAMETERS32_PTR pFromEgveParms
                                   , EGVE_PARAMETERS32_PTR pToEgveParms )
{

  /****************************************************************************/
  /* Copy over fields from the existing EGVE_PARAMETERS32 structure into the  */
  /* new one that IHSXTHCE needs, for a resource specific invocation.         */
  /****************************************************************************/
  pToEgveParms->client_handle     = pFromEgveParms->client_handle    ;
  pToEgveParms->command_indicator = pFromEgveParms->command_indicator;
  pToEgveParms->correlation_id    = pFromEgveParms->correlation_id   ;
  pToEgveParms->data_source       = pFromEgveParms->data_source      ;
  pToEgveParms->display_name      = pFromEgveParms->display_name     ;
  pToEgveParms->res_IBM_id        = pFromEgveParms->res_IBM_id       ;
  pToEgveParms->resource_status   = pFromEgveParms->resource_status  ;

  memcpy( pToEgveParms->op_id           , pFromEgveParms->op_id           , sizeof(pToEgveParms->op_id           ) );
  memcpy( pToEgveParms->client_ip_addr  , pFromEgveParms->client_ip_addr  , sizeof(pToEgveParms->client_ip_addr  ) );
  memcpy( pToEgveParms->server_ip_addr  , pFromEgveParms->server_ip_addr  , sizeof(pToEgveParms->server_ip_addr  ) );
  memcpy( pToEgveParms->resource_RODM_id, pFromEgveParms->resource_RODM_id, sizeof(pToEgveParms->resource_RODM_id) );

}


/******************************************************************************/
/*                                                                            */
/* Example of calling the IHSXTHCE command exit, and requesting that the      */
/* command responses be returned back directly from the IhsiSend API call.    */
/* The command responses will be printed out in the communication server's    */
/* command prompt window.  The console will not get any responses (neither the*/
/* command string or the command responses); nothing will show up in the      */
/* console's log window.                                                      */
/*                                                                            */
/******************************************************************************/
unsigned int IhsSamCE_IWantCommandResponses( EGVE_PARAMETERS32_PTR parms_ptr )
{

  #define NV390_SNATM_CMD "D NET,ID=%RESOURCE%"

  EGVE_PARAMETERS32 exit_parms;
  unsigned int      rc        = EGVE_EXIT_OK;

  memset( &exit_parms, 0x00, sizeof(exit_parms) );

  /****************************************************************************/
  /* Copy over fields from the existing EGVE_PARAMETERS32 structure into the  */
  /* new one that IHSXTHCE needs, for a resource specific invocation.         */
  /****************************************************************************/
  IhsSamCE_CopyFieldsForIhsxthce( parms_ptr
                                , &exit_parms );

  /****************************************************************************/
  /* Create the command string to execute on NetView390.                      */
  /****************************************************************************/
  exit_parms.command_string = (char *)malloc(strlen(NV390_SNATM_CMD) + 1);

  strcpy( exit_parms.command_string, NV390_SNATM_CMD );

  /****************************************************************************/
  /* Tell IHSXTHCE to wait at most 1 minute for the command responses.        */
  /****************************************************************************/
  exit_parms.wait_for_cmd_response  = 1;

  /****************************************************************************/
  /* Allocate plenty of storage.  This is where IHSXTHCE will place the       */
  /* command responses.                                                       */
  /****************************************************************************/
  exit_parms.user_data_length       = 30000;
  exit_parms.user_data              = (unsigned char *)calloc(exit_parms.user_data_length, 1);

  /****************************************************************************/
  /* Drive the IHSXTHCE command exit to send the command to NetView390.  Tell */
  /* IHSXTHCE to capture the command responses, and give them directly back to*/
  /* this command exit (will not forward the command responses to the         */
  /* console's log window).                                                   */
  /****************************************************************************/
  rc = IhsiSend( EXIT_NAME                  /* Source Exit name               */
               , "IHSXTHCE"                 /* Dest Exit name                 */
               , exit_parms.server_ip_addr  /* Dest IP address                */
               , &exit_parms );             /* Exit Paramters                 */

  /****************************************************************************/
  /* If successful                                                            */
  /****************************************************************************/
  if ( EGVE_EXIT_OK == rc )
  {
    /**************************************************************************/
    /* Print the Command Responses in the communication server's command      */
    /* prompt window.                                                         */
    /**************************************************************************/
    IhsSamCE_Cmd_Rsp( &exit_parms );

    /**************************************************************************/
    /* Tell the server to not echo the command string to the console's log    */
    /* upon return from this command exit.                                    */
    /**************************************************************************/
    parms_ptr->want_corr_of_cmd_rsps = 0;
  }

  /****************************************************************************/
  /* Else output an error message                                             */
  /****************************************************************************/
  else
  {
    printf( "IHSSAMCE.C:  Error occurred while calling IHSXTHCE.  rc is '%x'\n"
          , rc );
  }

  /****************************************************************************/
  /* Free up allocated memory                                                 */
  /****************************************************************************/
  free( exit_parms.user_data      );
  free( exit_parms.command_string );

  return( rc );

}


/******************************************************************************/
/*                                                                            */
/* Example of creating your own command responses, and sending these command  */
/* responses to the console's log window.                                     */
/*                                                                            */
/******************************************************************************/
unsigned int IhsSamCE_IWillBuildMyOwnCommandResponses( EGVE_PARAMETERS32_PTR parms_ptr )
{
  #define CMD_STR      "Sample command exit IHSSAMCE was invoked"
  #define CMD_RSP_STR1 "The resource name is "
  #define CMD_RSP_STR2 "The resource type is "

  unsigned int      rc        = EGVE_EXIT_OK;
  EGVE_CMD_RSP_PTR  pCmdRsp;
  EGVE_CMD_RSP_CTRL my_RSP_CTRL;

  memset( &my_RSP_CTRL, 0x00, sizeof(my_RSP_CTRL) );

  /****************************************************************************/
  /* If we really do have pointers to the resource name and resource type     */
  /* strings                                                                  */
  /****************************************************************************/
  if ( parms_ptr->display_name
    && parms_ptr->display_resource_type )
  {
    /**************************************************************************/
    /* This tells IHSXTJCR and the console that no more command respones will */
    /* follow.                                                                */
    /**************************************************************************/
    my_RSP_CTRL.isComplete = 1;

    parms_ptr->user_ctrl_data        = (unsigned char *)&my_RSP_CTRL;
    parms_ptr->user_ctrl_data_length = sizeof(my_RSP_CTRL);

    /**************************************************************************/
    /* Calculate how much of a buffer to malloc, and allocate it.             */
    /**************************************************************************/
    parms_ptr->user_data_length = 1 * EGVE_CMD_RSP_STR_OFFSET /* 1 cmd line   */
                                + 2 * EGVE_CMD_RSP_STR_OFFSET /* 2 cmd rsp str*/
                                + strlen( CMD_STR      ) + 1  /* the cmd line */
                                + strlen( CMD_RSP_STR1 ) + 1  /* 1st cmd rsp  */
                                + strlen( parms_ptr->display_name )
                                + strlen( CMD_RSP_STR2 ) + 1  /* 2nd cmd rsp  */
                                + strlen( parms_ptr->display_resource_type );

    parms_ptr->user_data = (unsigned char *)calloc(parms_ptr->user_data_length, 1);

    /**************************************************************************/
    /* Build the command string to display in the console's log window        */
    /**************************************************************************/
    pCmdRsp              = (EGVE_CMD_RSP_PTR)parms_ptr->user_data;
    pCmdRsp->cmdRspLen   = strlen( CMD_STR ) + 1;
    pCmdRsp->cmdRspType  = EGVE_CMD_RSP_TYPE_CMD;
    strcpy( pCmdRsp->cmdRspStr, CMD_STR );

    /**************************************************************************/
    /* Build first command response string                                    */
    /**************************************************************************/
    pCmdRsp = (EGVE_CMD_RSP_PTR)
              (  (unsigned char *)pCmdRsp
                + EGVE_CMD_RSP_STR_OFFSET
                + pCmdRsp->cmdRspLen );

    pCmdRsp->cmdRspLen   = strlen( CMD_RSP_STR1            )
                         + strlen( parms_ptr->display_name ) + 1;
    pCmdRsp->cmdRspType  = EGVE_CMD_RSP_TYPE_RSP;
    strcpy( pCmdRsp->cmdRspStr, CMD_RSP_STR1 );
    strcat( pCmdRsp->cmdRspStr, parms_ptr->display_name );

    /**************************************************************************/
    /* Build second command response string                                   */
    /**************************************************************************/
    pCmdRsp = (EGVE_CMD_RSP_PTR)
              (  (unsigned char *)pCmdRsp
                + EGVE_CMD_RSP_STR_OFFSET
                + pCmdRsp->cmdRspLen );

    pCmdRsp->cmdRspLen   = strlen( CMD_RSP_STR2                     )
                         + strlen( parms_ptr->display_resource_type ) + 1;
    pCmdRsp->cmdRspType  = EGVE_CMD_RSP_TYPE_RSP;
    strcpy( pCmdRsp->cmdRspStr, CMD_RSP_STR2 );
    strcat( pCmdRsp->cmdRspStr, parms_ptr->display_resource_type );

    /**************************************************************************/
    /* Send the command and the command response strings to the server        */
    /* provided command exit, which will send these strings to the console's  */
    /* log window.                                                            */
    /**************************************************************************/
    rc = IhsiSend( EXIT_NAME                /* Source Exit name               */
                 , "IHSXTJCR"               /* Dest Exit name                 */
                 , parms_ptr->server_ip_addr/* Dest IP address                */
                 , parms_ptr );             /* Exit Paramters                 */

    /**************************************************************************/
    /* If IHSXTJCR was invoked ok                                             */
    /**************************************************************************/
    if ( EGVE_EXIT_OK == rc )
    {
      /************************************************************************/
      /* Tell the server to not echo the command string to the console's log  */
      /* upon return the this command exit, because this command exit is doing*/
      /* this work.                                                           */
      /************************************************************************/
      parms_ptr->want_corr_of_cmd_rsps = 0;
    }

    /**************************************************************************/
    /* Else a failure occurred.                                               */
    /**************************************************************************/
    else
    {
      printf( "IHSSAMCE.C:  Error occurred while calling IHSXTJCR.  rc is '%x'\n"
            , rc );
    }

    /**************************************************************************/
    /* Free up allocated memory.  Since we are reusing the EGVE_PARAMETERS32  */
    /* structure passed to this exit, we need to clean it back up before this */
    /* command exit returns, so that the command exit facility doesn't attemp */
    /* to return this data to the caller.                                     */
    /**************************************************************************/
    free( parms_ptr->user_data );
          parms_ptr->user_data        = NULL;
          parms_ptr->user_data_length = 0;
  }

  /****************************************************************************/
  /* Else we unexpectantly got some null pointers                             */
  /****************************************************************************/
  else
  {
    printf( "IHSSAMCE.C error: Either display_name or display_resource_type was NULL.\n" );
    rc = EGVE_EXIT_INVALID_DEFINITION;
  }

  return( rc );

}


/******************************************************************************/
/*                                                                            */
/* Execute a NetView390 command, and let the IHSXTHCE handle the command      */
/* responses (IHSXTHCE will send the command responses to the console's log   */
/* window).                                                                   */
/*                                                                            */
/******************************************************************************/
unsigned int IhsSamCE_LetIhsxthceHandleCommandResponses( EGVE_PARAMETERS32_PTR parms_ptr )
{
  unsigned int      rc        = EGVE_EXIT_OK;

  /****************************************************************************/
  /* Drive the IHSXTHCE command exit to send the command to NetView390.  Let  */
  /* the server send the command string and all command responses to the      */
  /* console's log window.  It is assumed that the command_string field       */
  /* already contains a valid NetView390 command.                             */
  /****************************************************************************/
  rc = IhsiSend( EXIT_NAME                  /* Source Exit name               */
               , "IHSXTHCE"                 /* Dest Exit name                 */
               , parms_ptr->server_ip_addr  /* Dest IP address                */
               , parms_ptr );               /* Exit Paramters                 */

  /****************************************************************************/
  /* If IHSXTHCE was invoked ok                                               */
  /****************************************************************************/
  if ( EGVE_EXIT_OK == rc )
  {
    /**************************************************************************/
    /* Tell the server to echo the command string to the console's log.       */
    /**************************************************************************/
    parms_ptr->want_corr_of_cmd_rsps = 1;
  }
  /****************************************************************************/
  /* Else a failure occurred.                                                 */
  /****************************************************************************/
  else
  {
    printf( "IHSSAMCE.C:  Error occurred while calling IHSXTHCE.  rc is '%x'\n"
          , rc );
  }

  return( rc );

}


/******************************************************************************/
/*                                                                            */
/* This is the registered exit procedure.  The call to IhsiInitialize         */
/* specifies that this procedure should be called when the EXIT_NAME is       */
/* invoked by the console context menu.                                       */
/*                                                                            */
/******************************************************************************/
unsigned int XAPI exit_procedure( EGVE_PARAMETERS32_PTR parms_ptr )
{
  unsigned int exit_procedure_rc = EGVE_EXIT_OK;

  /****************************************************************************/
  /* If the context menu was for a resource                                   */
  /****************************************************************************/
  if ( 0 != parms_ptr->res_IBM_id )
  {
    /**************************************************************************/
    /* If this is a SNA Topology Manager (SNATM) resource                     */
    /**************************************************************************/
    if ( 5 == parms_ptr->data_source )
    {
      /************************************************************************/
      /* Execute a NetView390 command and ask for the command responses to be */
      /* returned to this command exit.                                       */
      /************************************************************************/
      exit_procedure_rc = IhsSamCE_IWantCommandResponses( parms_ptr );
    }
    /**************************************************************************/
    /* Else this is any resource besides SNATM                                */
    /**************************************************************************/
    else
    {
      /************************************************************************/
      /* Build the command string and command responses by this command exit  */
      /* and send them to the console.                                        */
      /************************************************************************/
      exit_procedure_rc = IhsSamCE_IWillBuildMyOwnCommandResponses( parms_ptr );
    }
  }
  /****************************************************************************/
  /* Else the context menu was over the background of the view                */
  /****************************************************************************/
  else
  {
    /**************************************************************************/
    /* Execute a NetView390 command, and let the IHSXTHCE handle the command  */
    /* responses (IHSXTHCE will send the command responses to the console).   */
    /**************************************************************************/
    exit_procedure_rc = IhsSamCE_LetIhsxthceHandleCommandResponses( parms_ptr );

  }

  return( exit_procedure_rc );
}

/******************************************************************************/
/*                                                                            */
/* This is the 'main' procedure.  It is invoked by the communication server   */
/* the first time that this command exit is called.  This procedure is called */
/* only once during the life of the communication server.                     */
/*                                                                            */
/******************************************************************************/
int main( int    argc
        , char **argv )
{

  /****************************************************************************/
  /* Register this command exit with the command exit facility of the         */
  /* communication server.                                                    */
  /****************************************************************************/
  IhsiInitialize( EXIT_NAME
                , exit_procedure );

  /****************************************************************************/
  /* Wait forever, until the communication server terminates.                 */
  /****************************************************************************/
  IhsiWait( EXIT_NAME
          , -1 );

  /****************************************************************************/
  /* Deregister this command exit from the communication server.              */
  /****************************************************************************/
  IhsiTerminate( EXIT_NAME );

  return( 0 );
}
