/*******************************************************************************
*
* Licensed Materials - Property of IBM
*
* This product contains "Restricted Materials of IBM"
*
* 5697-B82 (C) Copyright IBM Corp. 1997, 2001
* All Rights Reserved.
*
********************************************************************************
*
* PRODUCT          (NMC)
* COMPONENT        (IHSU)
*
* MODULE_NAME      (ihsuduix.h)
* DESCRIPTIVE_NAME (Definitions of Resource Types)
*
********************************************************************************
*
* Function:
*   Provides a mask to determine if a resource type is for a real or aggreagate resource.
*
*******************************************************************************/

/******************************************************************************/
/* Ensure we're only included once....                                        */
/******************************************************************************/
#ifndef _IHSUDUIX_ALREADY_INC

#define _IHSUDUIX_ALREADY_INC

/*******************************************************************************
* "Resource Type" AGGREGATE Attribute
*
* - This bit mask can be used to determine if a "Resource Type" value is
*   an aggregate or real resource.
*
* - Coding Sample:
*
*   if ( ResourceType & DUIXC_MASK_AGG_FLAG )
*     <this is an AGGREGATE resource>
*   else
*     <this is a  REAL      resource>
*
*******************************************************************************/
#define DUIXC_MASK_AGG_FLAG              0x80000000

/******************************************************************************/
/* Display_Resource_Type_Class, TypeNumber values.  The below are not all     */
/* of the DisplayResourceTypes that are defined in RODM.  The below are only  */
/* listed for migration reasons.  The below list is not complete.             */
/******************************************************************************/
#define DUIXC_LTN_GEN_NULL_LINK        0x00010051 /* Generic Null Link        */
#define DUIXC_LTN_LINK                 0x0001006E /* Link                     */

#define DUIXC_LTS_APPL_CONN            0x10010010 /* Appl. Connector          */
#define DUIXC_LTS_CLUSTER_CONN         0x90010001 /* Cluster Connection       */
#define DUIXC_LTS_GENERIC_LINK         0x10010014 /* Generic Link             */
#define DUIXC_LTS_HOST_HOST_CHAN       0x10010002 /* Host-Host Channel        */
#define DUIXC_LTS_HOST_HOST_CHAN_AGG   0x90010003 /* Host-Host Channel Agg    */
#define DUIXC_LTS_HOST_NCP_CHAN        0x10010004 /* Host-NCP Channel         */
#define DUIXC_LTS_HOST_NCP_CHAN_AGG    0x90010005 /* Host-NCP Channel Agg     */
#define DUIXC_LTS_HOST_NCP_CONN        0x9001000F /* Host-NCP Connector       */
#define DUIXC_LTS_NSWIT_LINK_AGG       0x90010007 /* Non-Switched Link Agg    */
#define DUIXC_LTS_NULL_CONN            0x10010012 /* Null Connector           */
#define DUIXC_LTS_PERIPH_LINK          0x10010013 /* Peripheral Link          */
#define DUIXC_LTS_SNA_LINE_AGG         0x90010018 /* SNA Line Aggregate       */
#define DUIXC_LTS_SWIT_LINK_AGG        0x90010009 /* Switched Link Agg        */
#define DUIXC_LTS_TG                   0x9001000A /* Transmission Group       */

#define DUIXC_RTN_APPL                 0x00040042 /* Application              */
#define DUIXC_RTN_APPN_EN              0x000500CB /* APPN End Node            */
#define DUIXC_RTN_APPN_NN              0x000500CA /* APPN Network Node        */
#define DUIXC_RTN_CROSS_DOMAIN_RES     0x00060072 /* Cross domain resource    */
#define DUIXC_RTN_GEN_NULL_NODE        0x00050068 /* Generic Null Node        */
#define DUIXC_RTN_INTERCHANGE_NODE     0x00030056 /* Interchange node         */
#define DUIXC_RTN_LOGICAL_LINK_PU      0x00080041 /* Logical link/PU          */
#define DUIXC_RTN_MIGRATION_DATA_HOST  0x00030058 /* Migration data host      */
#define DUIXC_RTN_NODE                 0x000500E9 /* Node                     */
#define DUIXC_RTN_NULL_NODE            0x00050060 /* Null Node                */

#define DUIXC_RTS_APPL_MAJ_NODE        0x1005000B /* Appl Maj Node            */
#define DUIXC_RTS_CDRSC                0x10050010 /* CDRSC                    */
#define DUIXC_RTS_CLUSTER              0x90020001 /* Cluster                  */
#define DUIXC_RTS_CONTROL_PT_NODE      0x10050019 /* Control Point Node       */
#define DUIXC_RTS_GATEWAY_HOST         0x10030003 /* Gateway Host             */
#define DUIXC_RTS_GATEWAY_NCP          0x10050014 /* Gateway NCP              */
#define DUIXC_RTS_GENERIC_PU           0x10050016 /* Generic PU               */
#define DUIXC_RTS_HOST                 0x10030001 /* Host (PU5)               */
#define DUIXC_RTS_HOST_AGG             0x90030002 /* Host (PU5) Agg.          */
#define DUIXC_RTS_LU                   0x10060001 /* LU                       */
#define DUIXC_RTS_NULL_NODE            0x10050011 /* Null Node                */
#define DUIXC_RTS_PU1                  0x1005001E /* PU 1                     */
#define DUIXC_RTS_PU1_ETHERNET         0x1005001D /* Physical Ethernet PU 1   */
#define DUIXC_RTS_PU1_FRAME_RELAY      0x1005001C /* Physical Frame Relay PU 1*/
#define DUIXC_RTS_PU1_NTRI             0x1005001B /* Physical NTRI PU 1       */
#define DUIXC_RTS_PU20                 0x10050003 /* Ctlr/3270 (PU 2.0)       */
#define DUIXC_RTS_PU21                 0x10050004 /* Ctlr/PWS (PU 2.1)        */
#define DUIXC_RTS_PU4                  0x10050001 /* Comm. Ctlr. (PU4)        */
#define DUIXC_RTS_PU4_AGG              0x90050002 /* Comm. Ctlr. Agg.         */
#define DUIXC_RTS_VTAM_APPL            0x10040001 /* VTAM Application         */

#endif                                 /* ensure only included once...        */
